/**
 * File navigation.js.
 *
 * Handles toggling the navigation menu for small screens and enables TAB key
 * navigation support for dropdown menus.
 */
( function() {
    var gridbone_secondary_container, gridbone_secondary_button, gridbone_secondary_menu, gridbone_secondary_links, gridbone_secondary_i, gridbone_secondary_len;

    gridbone_secondary_container = document.getElementById( 'gridbone-secondary-navigation' );
    if ( ! gridbone_secondary_container ) {
        return;
    }

    gridbone_secondary_button = gridbone_secondary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof gridbone_secondary_button ) {
        return;
    }

    gridbone_secondary_menu = gridbone_secondary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof gridbone_secondary_menu ) {
        gridbone_secondary_button.style.display = 'none';
        return;
    }

    gridbone_secondary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === gridbone_secondary_menu.className.indexOf( 'nav-menu' ) ) {
        gridbone_secondary_menu.className += ' nav-menu';
    }

    gridbone_secondary_button.onclick = function() {
        if ( -1 !== gridbone_secondary_container.className.indexOf( 'gridbone-toggled' ) ) {
            gridbone_secondary_container.className = gridbone_secondary_container.className.replace( ' gridbone-toggled', '' );
            gridbone_secondary_button.setAttribute( 'aria-expanded', 'false' );
            gridbone_secondary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            gridbone_secondary_container.className += ' gridbone-toggled';
            gridbone_secondary_button.setAttribute( 'aria-expanded', 'true' );
            gridbone_secondary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    gridbone_secondary_links    = gridbone_secondary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( gridbone_secondary_i = 0, gridbone_secondary_len = gridbone_secondary_links.length; gridbone_secondary_i < gridbone_secondary_len; gridbone_secondary_i++ ) {
        gridbone_secondary_links[gridbone_secondary_i].addEventListener( 'focus', gridbone_secondary_toggleFocus, true );
        gridbone_secondary_links[gridbone_secondary_i].addEventListener( 'blur', gridbone_secondary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function gridbone_secondary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'gridbone-focus' ) ) {
                    self.className = self.className.replace( ' gridbone-focus', '' );
                } else {
                    self.className += ' gridbone-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( gridbone_secondary_container ) {
        var touchStartFn, gridbone_secondary_i,
            parentLink = gridbone_secondary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, gridbone_secondary_i;

                if ( ! menuItem.classList.contains( 'gridbone-focus' ) ) {
                    e.preventDefault();
                    for ( gridbone_secondary_i = 0; gridbone_secondary_i < menuItem.parentNode.children.length; ++gridbone_secondary_i ) {
                        if ( menuItem === menuItem.parentNode.children[gridbone_secondary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[gridbone_secondary_i].classList.remove( 'gridbone-focus' );
                    }
                    menuItem.classList.add( 'gridbone-focus' );
                } else {
                    menuItem.classList.remove( 'gridbone-focus' );
                }
            };

            for ( gridbone_secondary_i = 0; gridbone_secondary_i < parentLink.length; ++gridbone_secondary_i ) {
                parentLink[gridbone_secondary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( gridbone_secondary_container ) );
} )();


( function() {
    var gridbone_primary_container, gridbone_primary_button, gridbone_primary_menu, gridbone_primary_links, gridbone_primary_i, gridbone_primary_len;

    gridbone_primary_container = document.getElementById( 'gridbone-primary-navigation' );
    if ( ! gridbone_primary_container ) {
        return;
    }

    gridbone_primary_button = gridbone_primary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof gridbone_primary_button ) {
        return;
    }

    gridbone_primary_menu = gridbone_primary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof gridbone_primary_menu ) {
        gridbone_primary_button.style.display = 'none';
        return;
    }

    gridbone_primary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === gridbone_primary_menu.className.indexOf( 'nav-menu' ) ) {
        gridbone_primary_menu.className += ' nav-menu';
    }

    gridbone_primary_button.onclick = function() {
        if ( -1 !== gridbone_primary_container.className.indexOf( 'gridbone-toggled' ) ) {
            gridbone_primary_container.className = gridbone_primary_container.className.replace( ' gridbone-toggled', '' );
            gridbone_primary_button.setAttribute( 'aria-expanded', 'false' );
            gridbone_primary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            gridbone_primary_container.className += ' gridbone-toggled';
            gridbone_primary_button.setAttribute( 'aria-expanded', 'true' );
            gridbone_primary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    gridbone_primary_links    = gridbone_primary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( gridbone_primary_i = 0, gridbone_primary_len = gridbone_primary_links.length; gridbone_primary_i < gridbone_primary_len; gridbone_primary_i++ ) {
        gridbone_primary_links[gridbone_primary_i].addEventListener( 'focus', gridbone_primary_toggleFocus, true );
        gridbone_primary_links[gridbone_primary_i].addEventListener( 'blur', gridbone_primary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function gridbone_primary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'gridbone-focus' ) ) {
                    self.className = self.className.replace( ' gridbone-focus', '' );
                } else {
                    self.className += ' gridbone-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( gridbone_primary_container ) {
        var touchStartFn, gridbone_primary_i,
            parentLink = gridbone_primary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, gridbone_primary_i;

                if ( ! menuItem.classList.contains( 'gridbone-focus' ) ) {
                    e.preventDefault();
                    for ( gridbone_primary_i = 0; gridbone_primary_i < menuItem.parentNode.children.length; ++gridbone_primary_i ) {
                        if ( menuItem === menuItem.parentNode.children[gridbone_primary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[gridbone_primary_i].classList.remove( 'gridbone-focus' );
                    }
                    menuItem.classList.add( 'gridbone-focus' );
                } else {
                    menuItem.classList.remove( 'gridbone-focus' );
                }
            };

            for ( gridbone_primary_i = 0; gridbone_primary_i < parentLink.length; ++gridbone_primary_i ) {
                parentLink[gridbone_primary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( gridbone_primary_container ) );
} )();