<?php
/**
* GridBone Theme Customizer.
*
* @package GridBone WordPress Theme
* @copyright Copyright (C) 2024 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

if ( ! class_exists( 'WP_Customize_Control' ) ) {return null;}

/**
* GridBone_Customize_Static_Text_Control class
*/

class GridBone_Customize_Static_Text_Control extends WP_Customize_Control {
    public $type = 'gridbone-static-text';

    public function __construct( $manager, $id, $args = array() ) {
        parent::__construct( $manager, $id, $args );
    }

    protected function render_content() {
        if ( ! empty( $this->label ) ) :
            ?><span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span><?php
        endif;

        if ( ! empty( $this->description ) ) :
            ?><div class="description customize-control-description"><?php

        echo wp_kses_post( $this->description );

            ?></div><?php
        endif;

    }
}

/**
* GridBone_Customize_Button_Control class
*/

class GridBone_Customize_Button_Control extends WP_Customize_Control {
        public $type = 'gridbone-button';
        protected $button_tag = 'button';
        protected $button_class = 'button button-primary';
        protected $button_href = 'javascript:void(0)';
        protected $button_target = '';
        protected $button_onclick = '';
        protected $button_tag_id = '';

        public function render_content() {
        ?>
        <span class="center">
        <?php
        echo '<' . esc_html($this->button_tag);
        if (!empty($this->button_class)) {
            echo ' class="' . esc_attr($this->button_class) . '"';
        }
        if ('button' == $this->button_tag) {
            echo ' type="button"';
        }
        else {
            echo ' href="' . esc_url($this->button_href) . '"' . (empty($this->button_tag) ? '' : ' target="' . esc_attr($this->button_target) . '"');
        }
        if (!empty($this->button_onclick)) {
            echo ' onclick="' . esc_js($this->button_onclick) . '"';
        }
        if (!empty($this->button_tag_id)) {
            echo ' id="' . esc_attr($this->button_tag_id) . '"';
        }
        echo '>';
        echo esc_html($this->label);
        echo '</' . esc_html($this->button_tag) . '>';
        ?>
        </span>
        <?php
        }
}




/**
* GridBone_Customize_Category_Control class
*/

class GridBone_Customize_Category_Control extends WP_Customize_Control {
    public $type = 'gridbone-dropdown-category';

    protected $dropdown_args = false;

    protected function render_content() {
        $input_id = '_customize-input-' . $this->id;
        $description_id = '_customize-description-' . $this->id;
        $describedby_attr = ( ! empty( $this->description ) ) ? ' aria-describedby="' . esc_attr( $description_id ) . '" ' : '';

        if ( ! empty( $this->label ) ) :
            ?><label for="<?php echo esc_attr( $input_id ); ?>" class="customize-control-title"><?php echo esc_html( $this->label ); ?></label><?php
        endif;

        if ( ! empty( $this->description ) ) :
            ?><span id="<?php echo esc_attr( $description_id ); ?>" class="description customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span><?php
        endif;

        $dropdown_args = wp_parse_args( $this->dropdown_args, array(
            'show_option_all'   => '',
            'show_option_none'  => '',
            'option_none_value' => 0,
            'orderby'           => 'id',
            'order'             => 'ASC',
            'show_count'        => 1,
            'hide_empty'        => 1,
            'child_of'          => 0,
            'exclude'           => '',
            'selected'          => $this->value(),
            'hierarchical'      => 1,
            'name'      => '',
            'id'      => esc_attr( $input_id ),
            'depth'             => 0,
            'tab_index'         => 0,
            'taxonomy'          => 'category',
            'hide_if_empty'     => false,
            'value_field'       => 'term_id',
        ) );

        $dropdown_args['echo'] = false;
        $dropdown = wp_dropdown_categories( $dropdown_args );
        $dropdown = str_replace( '<select', '<select ' . $this->get_link() . ' ' . $describedby_attr, $dropdown );
        echo wp_kses(
                    $dropdown,
                    array(
                        'select' => array(
                            'class' => array(),
                            'id' => array(),
                            'name' => array(),
                            'value' => array(),
                            'type' => array(),
                            'data-customize-setting-link' => array(),
                            'aria-describedby' => array()
                        ),
                        'option' => array(
                            'class' => array(),
                            'id' => array(),
                            'name' => array(),
                            'value' => array(),
                            'type' => array(),
                            'selected' => array()
                        ),
                    )
                );
    }
}




/**
* GridBone_Customize_Submit_Control class
*/

class GridBone_Customize_Submit_Control extends WP_Customize_Control {
        public $type = 'gridbone-submit-button';
        protected $button_class = '';
        protected $button_id = '';
        protected $button_value = '';
        protected $button_onclick = '';

        public function render_content() {
        ?>
        <form action="customize.php" method="get">
        <label>
        <span style="font-weight:normal;margin-bottom:10px;" class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
        <?php
        echo '<input type="submit"';
        if (!empty($this->button_class)) {
            echo ' class="' . esc_attr($this->button_class) . '"';
        }
        if (!empty($this->button_id)) {
            echo ' name="' . esc_attr($this->button_id) . '"';
        }
        if (!empty($this->button_id)) {
            echo ' id="' . esc_attr($this->button_id) . '"';
        }
        if (!empty($this->button_value)) {
            echo ' value="' . esc_attr($this->button_value) . '"';
        }
        if (!empty($this->button_onclick)) {
            echo ' onclick="return confirm(\'' . esc_js($this->button_onclick) . '\');"';
        }
        echo '/>';
        ?>
        </label>
        </form>
        <?php
        }
}

/**
* Sanitize callback functions
*/

function gridbone_sanitize_checkbox( $input ) {
    return ( ( isset( $input ) && ( true == $input ) ) ? true : false );
}

function gridbone_sanitize_html( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

function gridbone_sanitize_yes_no( $input, $setting ) {
    $valid = array('yes','no');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_date_type( $input, $setting ) {
    $valid = array('published','updated');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_grid_thumb_position( $input, $setting ) {
    $valid = array('top','bottom','left','right','center','initial');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_grid_title_style( $input, $setting ) {
    $valid = array('always-show','hover-show','hover-hide','always-hide');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_posts_navigation_type( $input, $setting ) {
    $valid = array('normalnavi','numberednavi');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_email( $input, $setting ) {
    if ( '' != $input && is_email( $input ) ) {
        $input = sanitize_email( $input );
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_logo_location( $input, $setting ) {
    $valid = array('beside-title','above-title');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_secondary_menu_location( $input, $setting ) {
    $valid = array(
            'before-header' => esc_html__('Before Header', 'gridbone'),
            'after-header' => esc_html__('After Header', 'gridbone'),
            'before-footer' => esc_html__('Before Footer', 'gridbone'),
            'after-footer' => esc_html__( 'After Footer', 'gridbone' )
    );

    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_positive_integer( $input, $setting ) {
    $input = absint( $input ); // Force the value into non-negative integer.
    return ( 0 < $input ) ? $input : $setting->default;
}

function gridbone_sanitize_slider_thumb_style( $input, $setting ) {
    $valid = array('gridbone-125w-125h-image','gridbone-480w-360h-image','gridbone-480w-480h-image');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_snippet_type( $input, $setting ) {
    $valid = array('postexcerpt','postcontent');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_header_notice_display( $input, $setting ) {
    $valid = array(
            'front-page' => esc_html__( 'Home Page', 'gridbone' ),
            'front-page-static' => esc_html__( 'Static Home Page', 'gridbone' ),
            'blog-posts-index' => esc_html__( 'Blog Posts Index Page', 'gridbone' ),
            'everywhere' => esc_html__( 'Everywhere', 'gridbone' )
    );

    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_footer_notice_display( $input, $setting ) {
    $valid = array(
            'front-page' => esc_html__( 'Home Page', 'gridbone' ),
            'front-page-static' => esc_html__( 'Static Home Page', 'gridbone' ),
            'blog-posts-index' => esc_html__( 'Blog Posts Index Page', 'gridbone' ),
            'everywhere' => esc_html__( 'Everywhere', 'gridbone' )
    );

    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_slider_display( $input, $setting ) {
    $valid = array(
            'front-page' => esc_html__( 'Home Page', 'gridbone' ),
            'front-page-static' => esc_html__( 'Static Home Page', 'gridbone' ),
            'blog-posts-index' => esc_html__( 'Blog Posts Index Page', 'gridbone' ),
            'everywhere' => esc_html__( 'Everywhere', 'gridbone' )
    );

    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_slider_post_type( $input, $setting ) {
    $valid = array('recentposts','catposts','tagposts');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_slider_post_orderby( $input, $setting ) {
    $valid = array('date','modified','comment_count');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_slider_post_order( $input, $setting ) {
    $valid = array('ASC','DESC');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_bg_size( $input, $setting ) {
    $valid = array('auto','cover','contain');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_bg_position( $input, $setting ) {
    $valid = array('left top','left center','left bottom','right top','right center','right bottom','center top','center center','center bottom');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_bg_attachment( $input, $setting ) {
    $valid = array('scroll','fixed','local');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_sanitize_bg_repeat( $input, $setting ) {
    $valid = array('repeat','repeat-x','repeat-y','no-repeat');
    if ( in_array( $input, $valid ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function gridbone_register_theme_customizer( $wp_customize ) {

    if(method_exists('WP_Customize_Manager', 'add_panel')):
    $wp_customize->add_panel('gridbone_main_options_panel', array( 'title' => esc_html__('Theme Options', 'gridbone'), 'priority' => 10, ));
    endif;

    $wp_customize->get_section( 'title_tagline' )->panel = 'gridbone_main_options_panel';
    $wp_customize->get_section( 'title_tagline' )->priority = 20;
    $wp_customize->get_section( 'header_image' )->panel = 'gridbone_main_options_panel';
    $wp_customize->get_section( 'header_image' )->priority = 26;
    $wp_customize->get_section( 'background_image' )->panel = 'gridbone_main_options_panel';
    $wp_customize->get_section( 'background_image' )->priority = 27;
    $wp_customize->get_section( 'colors' )->panel = 'gridbone_main_options_panel';
    $wp_customize->get_section( 'colors' )->priority = 40;
      
    $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
    $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
    $wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
    $wp_customize->get_setting( 'background_color' )->transport = 'postMessage';
    $wp_customize->get_control( 'background_color' )->description = esc_html__('To change Background Color, need to remove background image first:- go to Appearance : Customize : Theme Options : Background Image', 'gridbone');

    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'blogname', array(
            'selector'        => '.gridbone-site-title a',
            'render_callback' => 'gridbone_customize_partial_blogname',
        ) );
        $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
            'selector'        => '.gridbone-site-description',
            'render_callback' => 'gridbone_customize_partial_blogdescription',
        ) );
    }

    /* Getting started options */
    $wp_customize->add_section( 'gridbone_section_getting_started', array( 'title' => esc_html__( 'Getting Started', 'gridbone' ), 'description' => esc_html__( 'Thanks for your interest in GridBone! If you have any questions or run into any trouble, please visit us the following links. We will get you fixed up!', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 5, ) );

    $wp_customize->add_setting( 'gridbone_options[documentation]', array( 'default' => '', 'sanitize_callback' => '__return_false', ) );

    $wp_customize->add_control( new GridBone_Customize_Button_Control( $wp_customize, 'gridbone_documentation_control', array( 'label' => esc_html__( 'Documentation', 'gridbone' ), 'section' => 'gridbone_section_getting_started', 'settings' => 'gridbone_options[documentation]', 'type' => 'button', 'button_tag' => 'a', 'button_class' => 'button button-primary', 'button_href' => esc_url( 'https://themesdna.com/gridbone-wordpress-theme/' ), 'button_target' => '_blank', ) ) );

    $wp_customize->add_setting( 'gridbone_options[contact]', array( 'default' => '', 'sanitize_callback' => '__return_false', ) );

    $wp_customize->add_control( new GridBone_Customize_Button_Control( $wp_customize, 'gridbone_contact_control', array( 'label' => esc_html__( 'Contact Us', 'gridbone' ), 'section' => 'gridbone_section_getting_started', 'settings' => 'gridbone_options[contact]', 'type' => 'button', 'button_tag' => 'a', 'button_class' => 'button button-primary', 'button_href' => esc_url( 'https://themesdna.com/contact/' ), 'button_target' => '_blank', ) ) );

    /* Menu options */
    $wp_customize->add_section( 'gridbone_section_menu_options', array( 'title' => esc_html__( 'Menu Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 100 ) );

    $wp_customize->add_setting( 'gridbone_options[primary_menu_text]', array( 'default' => esc_html__( 'Menu', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_primary_menu_text_control', array( 'label' => esc_html__( 'Primary Menu Mobile Text', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[primary_menu_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_primary_menu]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_primary_menu_control', array( 'label' => esc_html__( 'Disable Primary Menu', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[disable_primary_menu]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_sticky_menu]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_sticky_menu_control', array( 'label' => esc_html__( 'Disable Sticky Feature from Primary Menu', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[disable_sticky_menu]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[enable_sticky_mobile_menu]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_sticky_mobile_menu_control', array( 'label' => esc_html__( 'Enable Sticky Feature for Primary Menu on Small Screen', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[enable_sticky_mobile_menu]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[center_primary_menu]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_center_primary_menu_control', array( 'label' => esc_html__( 'Center Primary Menu', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[center_primary_menu]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[secondary_menu_text]', array( 'default' => esc_html__( 'Menu', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_secondary_menu_text_control', array( 'label' => esc_html__( 'Secondary Menu Mobile Text', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[secondary_menu_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_secondary_menu]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_secondary_menu_control', array( 'label' => esc_html__( 'Disable Secondary Menu', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[disable_secondary_menu]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[center_secondary_menu]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_center_secondary_menu_control', array( 'label' => esc_html__( 'Center Secondary Menu', 'gridbone' ), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[center_secondary_menu]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[secondary_menu_location]', array( 'default' => 'before-header', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_secondary_menu_location' ) );

    $wp_customize->add_control( 'gridbone_secondary_menu_location_control', array( 'label' => esc_html__( 'Select Secondary Menu Location', 'gridbone' ), 'description' => esc_html__('Select where you want to display secondary menu.', 'gridbone'), 'section' => 'gridbone_section_menu_options', 'settings' => 'gridbone_options[secondary_menu_location]', 'type' => 'select', 'choices' => array( 'before-header' => esc_html__('Before Header', 'gridbone'), 'after-header' => esc_html__('After Header', 'gridbone'), 'before-footer' => esc_html__('Before Footer', 'gridbone'), 'after-footer' => esc_html__('After Footer', 'gridbone') ) ) );

    /* Header options */
    $wp_customize->add_section( 'gridbone_section_header', array( 'title' => esc_html__( 'Header Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 120 ) );

    $wp_customize->add_setting( 'gridbone_options[hide_tagline]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_tagline_control', array( 'label' => esc_html__( 'Hide Tagline', 'gridbone' ), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[hide_tagline]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_header_content]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_header_content_control', array( 'label' => esc_html__( 'Hide Header Content', 'gridbone' ), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[hide_header_content]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[logo_location]', array( 'default' => 'above-title', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_logo_location' ) );

    $wp_customize->add_control( 'gridbone_logo_location_control', array( 'label' => esc_html__( 'Logo Location', 'gridbone' ), 'description' => esc_html__('Select how you want to display the site logo with site title and tagline.', 'gridbone'), 'section' => 'title_tagline', 'settings' => 'gridbone_options[logo_location]', 'type' => 'select', 'choices' => array( 'beside-title' => esc_html__( 'Before Site Title and Tagline', 'gridbone' ), 'above-title' => esc_html__( 'Above Site Title and Tagline', 'gridbone' ) ), 'priority'   => 8 ) );

    $wp_customize->add_setting( 'gridbone_options[limit_logo_width]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_limit_logo_width_control', array( 'label' => esc_html__( 'Limit the Logo Width', 'gridbone' ), 'section' => 'title_tagline', 'settings' => 'gridbone_options[limit_logo_width]', 'type' => 'checkbox', 'priority'   => 8 ) );

    $wp_customize->add_setting( 'gridbone_options[logo_max_width]', array( 'default' => '300px', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridbone_logo_max_width_control', array( 'label' => esc_html__( 'Max Width of the Logo', 'gridbone' ), 'description' => esc_html__('Enter the max-width value for the logo. Default value is "300px". Note: This option has no effect until you check "Limit the Logo Width" option.', 'gridbone'), 'section' => 'title_tagline', 'settings' => 'gridbone_options[logo_max_width]', 'type' => 'text', 'priority'   => 8 ) );

    $wp_customize->add_setting( 'gridbone_options[hide_header_image]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_header_image_control', array( 'label' => esc_html__( 'Hide Header Image from Everywhere', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[hide_header_image]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[remove_header_image_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_remove_header_image_link_control', array( 'label' => esc_html__( 'Remove Link from Header Image', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[remove_header_image_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_header_image_details]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_header_image_details_control', array( 'label' => esc_html__( 'Hide both Title and Description from Header Image', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[hide_header_image_details]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_header_image_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_header_image_title_control', array( 'label' => esc_html__( 'Hide Title from Header Image', 'gridbone' ), 'description' => esc_html__('If you checked this option, header image title will be hidden from all screen sizes. This option has no effect if you have checked the option: "Hide both Title and Description from Header Image"', 'gridbone'), 'section' => 'header_image', 'settings' => 'gridbone_options[hide_header_image_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_header_image_description]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_header_image_description_control', array( 'label' => esc_html__( 'Hide Description from Header Image', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[hide_header_image_description]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_title_mobile]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_header_image_title_mobile_control', array( 'label' => esc_html__( 'Show Header Image Title on Smaller Screens', 'gridbone' ), 'description' => esc_html__('This option has no effect if you have checked any of these options: "Hide both Title and Description from Header Image", "Hide Title from Header Image"', 'gridbone'), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_title_mobile]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_description_mobile]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_header_image_description_mobile_control', array( 'label' => esc_html__( 'Show Header Image Description on Smaller Screens', 'gridbone' ), 'description' => esc_html__('This option has no effect if you have checked any of these options: "Hide both Title and Description from Header Image", "Hide Description from Header Image"', 'gridbone'), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_description_mobile]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_custom_text]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_header_image_custom_text_control', array( 'label' => esc_html__( 'Add Custom Title/Custom Description to Header Image', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_custom_text]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_custom_title]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_header_image_custom_title_control', array( 'label' => esc_html__( 'Header Image Custom Title', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_custom_title]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_custom_description]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_header_image_custom_description_control', array( 'label' => esc_html__( 'Header Image Custom Description', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_custom_description]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_destination]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_header_image_destination_control', array( 'label' => esc_html__( 'Header Image Destination URL', 'gridbone' ), 'description' => esc_html__( 'Enter the URL a visitor should go when he/she click on the header image. If you did not enter a URL below, header image will be linked to the homepage of your website.', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_destination]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_cover]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_header_image_cover_control', array( 'label' => esc_html__( 'Add a Minimum Height to Header Image on Smaller Screens', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_cover]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_image_height_mobile]', array( 'default' => '200px', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridbone_header_image_height_mobile_control', array( 'label' => esc_html__( 'Header Image Minimum Height on Smaller Screens', 'gridbone' ), 'description' => esc_html__('Enter the minimum height value for header image height. Default is 200px. Note: This option has no effect until you check "Add a Minimum Height to Header Image on Smaller Screens" option.', 'gridbone'), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_height_mobile]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[header_padding]', array( 'default' => '10px', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridbone_header_padding_control', array( 'label' => esc_html__( 'Header Padding', 'gridbone' ), 'description' => esc_html__('Enter the padding value for header content. Default is 10px.', 'gridbone'), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_padding]', 'type' => 'text' ) );

   $wp_customize->add_setting( 'gridbone_options[header_image_alt_text]', array( 'default' => get_bloginfo( 'name' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_header_image_alt_text_control', array( 'label' => esc_html__( 'Header Image Alt Text', 'gridbone' ), 'section' => 'header_image', 'settings' => 'gridbone_options[header_image_alt_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[search_box_placeholder_text]', array( 'default' => esc_html__( 'Enter your search keyword...', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_search_box_placeholder_text_control', array( 'label' => esc_html__( 'Search Box Placeholder Text', 'gridbone' ), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[search_box_placeholder_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[enable_header_notice]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_header_notice_control', array( 'label' => esc_html__( 'Enable Header Notice', 'gridbone' ), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[enable_header_notice]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_notice_text]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_header_notice_text_control', array( 'label' => esc_html__( 'Header Notice', 'gridbone' ), 'description' => esc_html__( 'Enter a message to display in the header notification area. You can add custom text or an ad code here.', 'gridbone' ), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_notice_text]', 'type' => 'textarea' ) );

    $wp_customize->add_setting( 'gridbone_options[header_notice_display]', array( 'default' => 'everywhere', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_header_notice_display' ) );

    $wp_customize->add_control( 'gridbone_header_notice_display_control', array( 'label' => esc_html__( 'Header Notice Display Location', 'gridbone' ), 'description' => esc_html__('Select the header notice display location.', 'gridbone'), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_notice_display]', 'type' => 'select', 'choices' => array( 'front-page' => esc_html__('Home Page', 'gridbone'), 'front-page-static' => esc_html__('Static Home Page', 'gridbone'), 'blog-posts-index' => esc_html__( 'Blog Posts Index Page', 'gridbone' ), 'everywhere' => esc_html__('Everywhere', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[no_center_header_notice]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_no_center_header_notice_control', array( 'label' => esc_html__( 'Do not Center Header Notice', 'gridbone' ), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[no_center_header_notice]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[header_content_image]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'absint' ) );

    $wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'gridbone_header_content_image_control', array(
        'label' => esc_html__( 'Header Content Background Image', 'gridbone' ),
        'flex_width' => true,
        'flex_height' => true,
        'section' => 'gridbone_section_header',
        'settings' => 'gridbone_options[header_content_image]',
        'button_labels' => array( 'select' => esc_html__( 'Select Image', 'gridbone' ), 'remove' => esc_html__( 'Remove Image', 'gridbone' ), 'change' => esc_html__( 'Change Image', 'gridbone' ), )
    )));

    $wp_customize->add_setting( 'gridbone_options[header_content_bg_size]', array( 'default' => 'cover', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_size' ) );

    $wp_customize->add_control( 'gridbone_header_content_bg_size_control', array( 'label' => esc_html__( 'Header Content Background Image Size', 'gridbone' ), 'description' => esc_html__('Select the background size value for header content background image. Default value: Cover', 'gridbone'), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_content_bg_size]', 'type' => 'select', 'choices' => array( 'auto' => esc_html__( 'Auto', 'gridbone' ), 'cover' => esc_html__( 'Cover', 'gridbone' ), 'contain' => esc_html__( 'Contain', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[header_content_bg_position]', array( 'default' => 'center top', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_position' ) );

    $wp_customize->add_control( 'gridbone_header_content_bg_position_control', array( 'label' => esc_html__( 'Header Content Background Image Position', 'gridbone' ), 'description' => esc_html__('Select the background position value for header content background image. Default value: Center Top', 'gridbone'), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_content_bg_position]', 'type' => 'select', 'choices' => array( 'left top' => esc_html__( 'Left Top', 'gridbone' ), 'left center' => esc_html__( 'Left Center', 'gridbone' ), 'left bottom' => esc_html__( 'Left Bottom', 'gridbone' ), 'right top' => esc_html__( 'Right Top', 'gridbone' ), 'right center' => esc_html__( 'Right Center', 'gridbone' ), 'right bottom' => esc_html__( 'Right Bottom', 'gridbone' ), 'center top' => esc_html__( 'Center Top', 'gridbone' ), 'center center' => esc_html__( 'Center Center', 'gridbone' ), 'center bottom' => esc_html__( 'Center Bottom', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[header_content_bg_attachment]', array( 'default' => 'scroll', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_attachment' ) );

    $wp_customize->add_control( 'gridbone_header_content_bg_attachment_control', array( 'label' => esc_html__( 'Header Content Background Image Attachment', 'gridbone' ), 'description' => esc_html__('Select the background attachment value for header content background image. Default value: Scroll', 'gridbone'), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_content_bg_attachment]', 'type' => 'select', 'choices' => array( 'scroll' => esc_html__( 'Scroll', 'gridbone' ), 'fixed' => esc_html__( 'Fixed', 'gridbone' ), 'local' => esc_html__( 'Local', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[header_content_bg_repeat]', array( 'default' => 'no-repeat', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_repeat' ) );

    $wp_customize->add_control( 'gridbone_header_content_bg_repeat_control', array( 'label' => esc_html__( 'Header Content Background Image Repeat', 'gridbone' ), 'description' => esc_html__('Select the background repeat value for header content background image. Default value: no-repeat', 'gridbone'), 'section' => 'gridbone_section_header', 'settings' => 'gridbone_options[header_content_bg_repeat]', 'type' => 'select', 'choices' => array( 'repeat' => esc_html__( 'repeat', 'gridbone' ), 'repeat-x' => esc_html__( 'repeat-x', 'gridbone' ), 'repeat-y' => esc_html__( 'repeat-y', 'gridbone' ), 'no-repeat' => esc_html__( 'no-repeat', 'gridbone' ) ) ) );


    /* Slider options */
    $wp_customize->add_section( 'gridbone_section_slider', array( 'title' => esc_html__( 'Slider Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 145 ) );

    $wp_customize->add_setting( 'gridbone_options[enable_slider]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_slider_control', array( 'label' => esc_html__( 'Enable Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[enable_slider]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[show_slider_heading]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_show_slider_heading_control', array( 'label' => esc_html__( 'Show Slider Heading', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[show_slider_heading]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slider_heading]', array( 'default' => esc_html__( 'Featured Posts Slider', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_slider_heading_control', array( 'label' => esc_html__( 'Slider Heading', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_heading]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[slider_display]', array( 'default' => 'front-page', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_slider_display' ) );

    $wp_customize->add_control( 'gridbone_slider_display_control', array( 'label' => esc_html__( 'Slider Display Location', 'gridbone' ), 'description' => esc_html__('Select the slider display location.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_display]', 'type' => 'select', 'choices' => array( 'front-page' => esc_html__('Home Page', 'gridbone'), 'front-page-static' => esc_html__('Static Home Page', 'gridbone'), 'blog-posts-index' => esc_html__( 'Blog Posts Index Page', 'gridbone' ), 'everywhere' => esc_html__('Everywhere', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[slider_length]', array( 'default' => 10, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_slider_length_control', array( 'label' => esc_html__( 'Number of Posts on Slider', 'gridbone' ), 'description' => esc_html__('Enter the number of posts you need to display in the slider area. Default is 10 posts.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_length]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[slider_post_type]', array( 'default' => 'recentposts', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_slider_post_type' ) );

    $wp_customize->add_control( 'gridbone_slider_post_type_control', array( 'label' => esc_html__( 'Slider Posts Type', 'gridbone' ), 'description' => esc_html__('Select a post type to display in slider.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_post_type]', 'type' => 'select', 'choices' => array( 'recentposts' => esc_html__( 'Recent Posts', 'gridbone' ), 'catposts' => esc_html__( 'Category Posts', 'gridbone' ), 'tagposts' => esc_html__( 'Tag Posts', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[slider_cat]', array( 'default' => 0, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'absint' ) );

    $wp_customize->add_control( new GridBone_Customize_Category_Control( $wp_customize, 'gridbone_slider_cat_control', array( 'label' => esc_html__( 'Slider Posts Category', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_cat]', 'description' => esc_html__( 'Select a category if "Slider Posts Type" option is Category Posts', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[slider_tag]', array( 'default' => 0, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'absint' ) );

    $wp_customize->add_control( new GridBone_Customize_Category_Control( $wp_customize, 'gridbone_slider_tag_control', array( 'label' => esc_html__( 'Slider Posts Tag', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_tag]', 'description' => esc_html__( 'Select a tag if "Slider Posts Type" option is Tag Posts', 'gridbone' ), 'dropdown_args' => array( 'taxonomy' => 'post_tag', ), ) ) );

    $wp_customize->add_setting( 'gridbone_options[slider_post_orderby]', array( 'default' => 'date', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_slider_post_orderby' ) );

    $wp_customize->add_control( 'gridbone_slider_post_orderby_control', array( 'label' => esc_html__( 'Slider Posts Orderby', 'gridbone' ), 'description' => esc_html__('Select a posts orderby value for slider.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_post_orderby]', 'type' => 'select', 'choices' => array( 'date' => esc_html__( 'Published Date', 'gridbone' ), 'modified' => esc_html__( 'Modified Date', 'gridbone' ), 'comment_count' => esc_html__( 'Number of Comments', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[slider_post_order]', array( 'default' => 'DESC', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_slider_post_order' ) );

    $wp_customize->add_control( 'gridbone_slider_post_order_control', array( 'label' => esc_html__( 'Slider Posts Order', 'gridbone' ), 'description' => esc_html__('Select a posts order value for slider.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_post_order]', 'type' => 'select', 'choices' => array( 'ASC' => esc_html__( 'Ascending order', 'gridbone' ), 'DESC' => esc_html__( 'Descending order', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[slider_thumb_style]', array( 'default' => 'gridbone-480w-480h-image', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_slider_thumb_style' ) );

    $wp_customize->add_control( 'gridbone_slider_thumb_style_control', array( 'label' => esc_html__( 'Featured Images Size of Slider', 'gridbone' ), 'description' => esc_html__('Select the thumbnail size you need for the slider.If you select "Custom Size" value, please set thumbnail width and height going to "Appearance" : "Customize" : "Theme Options" : "Posts Summaries Options". After that regenerate your thumbnails using a plugin like "Regenerate Thumbnails".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_thumb_style]', 'type' => 'select', 'choices' => array( 'gridbone-125w-125h-image' => esc_html__('125:125 Thumbnails', 'gridbone'), 'gridbone-480w-360h-image' => esc_html__('480:360 Thumbnails', 'gridbone'), 'gridbone-480w-480h-image' => esc_html__('480:480 Thumbnails', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[hide_thumbnail_slider]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_thumbnail_slider_control', array( 'label' => esc_html__( 'Hide Featured Images from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_thumbnail_slider]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_default_thumbnail_slider]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_default_thumbnail_slider_control', array( 'label' => esc_html__( 'Hide Default Featured Image from Slider', 'gridbone' ), 'description' => esc_html__( 'The default thumbnail image is shown when there is no featured image is set.', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_default_thumbnail_slider]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[remove_thumbnail_slider_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_remove_thumbnail_slider_link_control', array( 'label' => esc_html__( 'Remove Links from Slider Featured Images', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[remove_thumbnail_slider_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_post_title_slider]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_title_slider_control', array( 'label' => esc_html__( 'Hide Post Titles from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_post_title_slider]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[remove_post_title_slider_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_remove_post_title_slider_link_control', array( 'label' => esc_html__( 'Remove Links from Slider Post Titles', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[remove_post_title_slider_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[limit_slider_post_titles]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_limit_slider_post_titles_control', array( 'label' => esc_html__( 'Limit the Length of Slider Post Titles', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[limit_slider_post_titles]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_title_length_slider]', array( 'default' => 6, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_post_title_length_slider_control', array( 'label' => esc_html__( 'Maximum Length of Slider Post Titles', 'gridbone' ), 'description' => esc_html__('Enter the maximum number of words need to display in slider post titles. Default is 8 words. This option only work if you have check the option "Limit the Length of Slider Post Titles".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[post_title_length_slider]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[hide_slide_author]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_slide_author_control', array( 'label' => esc_html__( 'Hide Post Authors from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_slide_author]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slide_author_text]', array( 'default' => esc_html__( 'By', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_slide_author_text_control', array( 'label' => esc_html__( 'Slider Post Author Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post author. Default text is "Posted by".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slide_author_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_slide_date]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_slide_date_control', array( 'label' => esc_html__( 'Hide Posted Dates from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_slide_date]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slider_dateformat]', array( 'default' => 'F j, Y', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_slider_dateformat_control', array( 'label' => esc_html__( 'Slider Date Format', 'gridbone' ), 'description' => esc_html__('Default value: F j, Y', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_dateformat]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[slide_date_type]', array( 'default' => 'updated', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_date_type' ) );

    $wp_customize->add_control( 'gridbone_slide_date_type_control', array( 'label' => esc_html__( 'Slider Post Date Type', 'gridbone' ), 'description' => esc_html__('You can choose to display published or updated date of your post.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slide_date_type]', 'type' => 'select', 'choices' => array( 'published' => esc_html__('Published', 'gridbone'), 'updated' => esc_html__('Updated', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[slide_published_date_text]', array( 'default' => esc_html__( 'Posted on', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_slide_published_date_text_control', array( 'label' => esc_html__( 'Slider Post Published Date Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before published post date. Default text is "Posted on".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slide_published_date_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[slide_updated_date_text]', array( 'default' => esc_html__( 'Updated on', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_slide_updated_date_text_control', array( 'label' => esc_html__( 'Slider Post Updated Date Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post updated date. Default text is "Last updated on".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slide_updated_date_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[show_slide_comments]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_show_slide_comments_control', array( 'label' => esc_html__( 'Show Post Comments on Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[show_slide_comments]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slide_comments_text]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_slide_comments_text_control', array( 'label' => esc_html__( 'Slider Post Comments Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post comments.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slide_comments_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_slide_cats]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_slide_cats_control', array( 'label' => esc_html__( 'Hide Post Categories from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_slide_cats]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[show_slide_tags]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_show_slide_tags_control', array( 'label' => esc_html__( 'Show Post Tags on Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[show_slide_tags]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slide_tag_links_text]', array( 'default' => esc_html__( 'Tagged', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_slide_tag_links_text_control', array( 'label' => esc_html__( 'Slider Post Tags Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post tags. Default text is "Tagged".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slide_tag_links_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_post_snippet_slider]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_snippet_slider_control', array( 'label' => esc_html__( 'Hide Post Snippets from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_post_snippet_slider]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[snippet_type_slider]', array( 'default' => 'postexcerpt', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_snippet_type' ) );

    $wp_customize->add_control( 'gridbone_snippet_type_slider_control', array( 'label' => esc_html__( 'Post Snippets Type of Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[snippet_type_slider]', 'type' => 'select', 'choices' => array( 'postexcerpt' => esc_html__('Post Excerpt', 'gridbone'), 'postcontent' => esc_html__('Post Content', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[snippet_length_slider]', array( 'default' => 17, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_snippet_length_slider_control', array( 'label' => esc_html__( 'Post Snippets Length of Slider', 'gridbone' ), 'description' => esc_html__('Enter the number of words need to display in slider post summaries. Default is 17 words. This option only work if you have selected "Post Content" value for "Post Snippets Type of Slider" option. To change "Post Excerpt" length, go to Appearance : Customize : Theme Options : Posts Summaries Options : Post Snippets Length of Grid Posts Summaries.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[snippet_length_slider]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[center_slide_content]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_center_slide_content_control', array( 'label' => esc_html__( 'Center the Content of Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[center_slide_content]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slider_autoplay]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_slider_autoplay_control', array( 'label' => esc_html__( 'Enable Autoplay for Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_autoplay]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slider_autoplayhoverpause]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_slider_autoplayhoverpause_control', array( 'label' => esc_html__( 'Enable "Pause on Mouse Hover" Feature for Slider', 'gridbone' ), 'description' => esc_html__('When you enable this feature, slides will pause on mouse hover. This option has no effect until you check the option "Enable Autoplay for Slider".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_autoplayhoverpause]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[slider_autoplaytimeout]', array( 'default' => 1000, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_slider_autoplaytimeout_control', array( 'label' => esc_html__( 'Slider "Autoplay Interval Timeout"', 'gridbone' ), 'description' => esc_html__('Enter the slider autoplay interval timeout in milliseconds. Default is 1000. This option has no effect until you check the option "Enable Autoplay for Slider".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_autoplaytimeout]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[slider_autoplayspeed]', array( 'default' => 200, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_slider_autoplayspeed_control', array( 'label' => esc_html__( 'Slider "Autoplay Speed"', 'gridbone' ), 'description' => esc_html__('Enter the slider autoplay speed in milliseconds. Default is 200. This option has no effect until you check the option "Enable Autoplay for Slider".', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_autoplayspeed]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[slider_loop]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_slider_loop_control', array( 'label' => esc_html__( 'Enable "Loop" Feature for Slider', 'gridbone' ), 'description' => esc_html__('When you enable this feature, it will duplicate last and first slide items to get loop illusion.', 'gridbone'), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[slider_loop]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[show_dots_pagination]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_show_dots_pagination_control', array( 'label' => esc_html__( 'Show Dots Navigation(Pagination) on Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[show_dots_pagination]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_next_prev_navigation]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_next_prev_navigation_control', array( 'label' => esc_html__( 'Hide next/prev Buttons(Navigation) from Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[hide_next_prev_navigation]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[enable_autoheight]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_autoheight_control', array( 'label' => esc_html__( 'Enable "Auto Height" Feature on Slider', 'gridbone' ), 'section' => 'gridbone_section_slider', 'settings' => 'gridbone_options[enable_autoheight]', 'type' => 'checkbox', ) );


    /* Posts Grid options */
    $wp_customize->add_section( 'gridbone_section_posts_grid', array( 'title' => esc_html__( 'Posts Grid Options', 'gridbone' ), 'description' => esc_html__('To display your latest posts as a grid on your homepage, please set the "Your homepage displays" option to "Your latest posts." You can find this setting in your WordPress Dashboard by navigating to "Settings" -> "Reading" -> "Your homepage displays."', 'gridbone'), 'panel' => 'gridbone_main_options_panel', 'priority' => 160 ) );

    $wp_customize->add_setting( 'gridbone_options[hide_posts_home]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_posts_home_control', array( 'label' => esc_html__( 'Hide Blog Posts from HomePage', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[hide_posts_home]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_posts_heading]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_posts_heading_control', array( 'label' => esc_html__( 'Hide HomePage Posts Heading', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[hide_posts_heading]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[posts_heading]', array( 'default' => esc_html__( 'Recent Posts', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_posts_heading_control', array( 'label' => esc_html__( 'HomePage Posts Heading', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[posts_heading]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'posts_per_page', array( 'default' => get_option('posts_per_page'), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_posts_per_page_control', array( 'label' => esc_html__( 'Number of Posts per Page', 'gridbone' ), 'description' => esc_html__('Set the maximum number of posts displayed on each blog page.', 'gridbone'), 'section' => 'gridbone_section_posts_grid', 'settings' => 'posts_per_page', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[grid_link_disable]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_grid_link_disable_control', array( 'label' => esc_html__( 'Remove Grid URLs', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[grid_link_disable]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[grid_thumb_position]', array( 'default' => 'top', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_grid_thumb_position' ) );

    $wp_customize->add_control( 'gridbone_grid_thumb_position_control', array( 'label' => esc_html__( 'Grid Thumbnails Background Position', 'gridbone' ), 'description' => esc_html__('Select the background position of thumbnails in the post grid. Default value is "top"', 'gridbone'), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[grid_thumb_position]', 'type' => 'select', 'choices' => array( 'top' => esc_html__('Top', 'gridbone'), 'bottom' => esc_html__('Bottom', 'gridbone'), 'left' => esc_html__('Left', 'gridbone'), 'right' => esc_html__('Right', 'gridbone'), 'center' => esc_html__('Center', 'gridbone'), 'initial' => esc_html__('Initial', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[hide_grid_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_grid_title_control', array( 'label' => esc_html__( 'Hide Grid Titles', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[hide_grid_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[grid_title_style]', array( 'default' => 'always-show', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_grid_title_style' ) );

    $wp_customize->add_control( 'gridbone_grid_title_style_control', array( 'label' => esc_html__( 'Grid Titles Display Style', 'gridbone' ), 'description' => esc_html__('Select the display method of titles in the post grid. Default value is "Always show titles"', 'gridbone'), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[grid_title_style]', 'type' => 'select', 'choices' => array( 'always-show' => esc_html__('Always show titles', 'gridbone'), 'hover-show' => esc_html__('Display titles when hovering over', 'gridbone'), 'hover-hide' => esc_html__('Hide titles when hovering over', 'gridbone'), 'always-hide' => esc_html__('Always hide titles', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[limit_grid_titles]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_limit_grid_titles_control', array( 'label' => esc_html__( 'Limit the Length of Grid Titles', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[limit_grid_titles]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[grid_title_length]', array( 'default' => 6, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_grid_title_length_control', array( 'label' => esc_html__( 'Maximum Length of Grid Titles', 'gridbone' ), 'description' => esc_html__('Enter the maximum number of words need to display in grid titles. Default is 6 words. This option only work if you have check the option "Limit the Length of Grid Titles".', 'gridbone'), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[grid_title_length]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[remove_grid_item_borders]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_remove_grid_item_borders_control', array( 'label' => esc_html__( 'Remove Borders from Grid Posts', 'gridbone' ), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[remove_grid_item_borders]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[grid_item_border_radius]', array( 'default' => '0px', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridbone_grid_item_border_radius_control', array( 'label' => esc_html__( 'Border Radius of Grid Posts', 'gridbone' ), 'description' => esc_html__('Enter a border-radius value of grid posts in your posts grid. Default value is "0px"', 'gridbone'), 'section' => 'gridbone_section_posts_grid', 'settings' => 'gridbone_options[grid_item_border_radius]', 'type' => 'text' ) );

    /* Post options */
    $wp_customize->add_section( 'gridbone_section_post', array( 'title' => esc_html__( 'Post Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 180 ) );

    $wp_customize->add_setting( 'gridbone_options[thumbnail_link]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_yes_no' ) );

    $wp_customize->add_control( 'gridbone_thumbnail_link_control', array( 'label' => esc_html__( 'Featured Image Link', 'gridbone' ), 'description' => esc_html__('Do you want the featured image in a single post to be linked to its post?', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[thumbnail_link]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'gridbone'), 'no' => esc_html__('No', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[hide_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_thumbnail_control', array( 'label' => esc_html__( 'Hide Featured Image from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[featured_media_under_post_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_featured_media_under_post_title_control', array( 'label' => esc_html__( 'Move Featured Image to Bottom of Full Post Title', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[featured_media_under_post_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[auto_width_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_auto_width_thumbnail_control', array( 'label' => esc_html__( 'Do not Stretch Small Featured Image in Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[auto_width_thumbnail]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_breadcrumbs]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_breadcrumbs_control', array( 'label' => esc_html__( 'Hide Breadcrumbs from Full Post', 'gridbone' ), 'description' => esc_html__('Note: You need to install and activate "Yoast SEO" plugin to display breadcrumbs.', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_breadcrumbs]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_title_control', array( 'label' => esc_html__( 'Hide Post Header from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[remove_post_title_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_remove_post_title_link_control', array( 'label' => esc_html__( 'Remove Link from Full Post Title', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[remove_post_title_link]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_date]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_date_control', array( 'label' => esc_html__( 'Hide Post Date from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_date]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_date_type]', array( 'default' => 'updated', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_date_type' ) );

    $wp_customize->add_control( 'gridbone_post_date_type_control', array( 'label' => esc_html__( 'Post Date Type', 'gridbone' ), 'description' => esc_html__('You can choose to display published or updated date of your post.', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_date_type]', 'type' => 'select', 'choices' => array( 'published' => esc_html__('Published', 'gridbone'), 'updated' => esc_html__('Updated', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[post_published_date_text]', array( 'default' => esc_html__( 'Posted on', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_published_date_text_control', array( 'label' => esc_html__( 'Post Published Date Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before published post date. Default text is "Posted on".', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_published_date_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[post_updated_date_text]', array( 'default' => esc_html__( 'Last updated on', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_updated_date_text_control', array( 'label' => esc_html__( 'Post Updated Date Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post updated date. Default text is "Last updated on".', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_updated_date_text]', 'type' => 'text', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_author]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_author_control', array( 'label' => esc_html__( 'Hide Post Author from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_author]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_author_text]', array( 'default' => esc_html__( 'Posted by', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_author_text_control', array( 'label' => esc_html__( 'Post Author Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post author. Default text is "Posted by".', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_author_text]', 'type' => 'text', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_categories]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_categories_control', array( 'label' => esc_html__( 'Hide Post Categories from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_categories]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_cat_links_text]', array( 'default' => esc_html__( 'Posted in', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_cat_links_text_control', array( 'label' => esc_html__( 'Post Categories Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post categories. Default text is "Posted in".', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_cat_links_text]', 'type' => 'text', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_tags]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_tags_control', array( 'label' => esc_html__( 'Hide Post Tags from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_tags]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_tag_links_text]', array( 'default' => esc_html__( 'Tagged', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_tag_links_text_control', array( 'label' => esc_html__( 'Post Tags Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post tags. Default text is "Tagged".', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_tag_links_text]', 'type' => 'text', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_comments_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_comments_link_control', array( 'label' => esc_html__( 'Hide Comment Link from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_comments_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_comments_text]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_comments_text_control', array( 'label' => esc_html__( 'Post Comments Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before post comments.', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_comments_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_comment_form]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_comment_form_control', array( 'label' => esc_html__( 'Hide Comments/Comment Form from Full Post', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_comment_form]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_post_edit]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_edit_control', array( 'label' => esc_html__( 'Hide Post Edit Link', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_post_edit]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'gridbone_options[hide_author_bio_box]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_author_bio_box_control', array( 'label' => esc_html__( 'Hide Author Bio Box', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[hide_author_bio_box]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[read_more_length]', array( 'default' => 17, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_positive_integer' ) );

    $wp_customize->add_control( 'gridbone_read_more_length_control', array( 'label' => esc_html__( 'Post Excerpt Length', 'gridbone' ), 'description' => esc_html__('Enter the number of words need to display in post excerpts. Default is 17 words.', 'gridbone'), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[read_more_length]', 'type' => 'text' ) );


    $wp_customize->add_setting( 'gridbone_options[no_underline_content_links]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_no_underline_content_links_control', array( 'label' => esc_html__( 'Do not Underline the Links within the Content', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[no_underline_content_links]', 'type' => 'checkbox', ) );


    $wp_customize->add_setting( 'gridbone_options[enable_post_ad_one]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_post_ad_one_control', array( 'label' => esc_html__( 'Show Post Ad 1', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[enable_post_ad_one]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_ad_one_code]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_ad_one_code_control', array( 'label' => esc_html__( 'Post Ad 1 Code', 'gridbone' ), 'description' => esc_html__( 'This ad is located under post title.', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_ad_one_code]', 'type' => 'textarea' ) );

    $wp_customize->add_setting( 'gridbone_options[no_center_post_ad_one]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_no_center_post_ad_one_control', array( 'label' => esc_html__( 'Do not Center Post Ad 1', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[no_center_post_ad_one]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[enable_post_ad_two]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_post_ad_two_control', array( 'label' => esc_html__( 'Show Post Ad 2', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[enable_post_ad_two]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[post_ad_two_code]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_post_ad_two_code_control', array( 'label' => esc_html__( 'Post Ad 2 Code', 'gridbone' ), 'description' => esc_html__( 'This ad is located under post content.', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[post_ad_two_code]', 'type' => 'textarea' ) );

    $wp_customize->add_setting( 'gridbone_options[no_center_post_ad_two]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_no_center_post_ad_two_control', array( 'label' => esc_html__( 'Do not Center Post Ad 2', 'gridbone' ), 'section' => 'gridbone_section_post', 'settings' => 'gridbone_options[no_center_post_ad_two]', 'type' => 'checkbox', ) );


    /* Navigation options */
    $wp_customize->add_section( 'gridbone_section_navigation', array( 'title' => esc_html__( 'Posts Navigation Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 185 ) );

    $wp_customize->add_setting( 'gridbone_options[hide_post_navigation]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_post_navigation_control', array( 'label' => esc_html__( 'Hide Post Navigation from Full Posts', 'gridbone' ), 'section' => 'gridbone_section_navigation', 'settings' => 'gridbone_options[hide_post_navigation]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_posts_navigation]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_posts_navigation_control', array( 'label' => esc_html__( 'Hide Posts Navigation from Home/Archive/Search Pages', 'gridbone' ), 'section' => 'gridbone_section_navigation', 'settings' => 'gridbone_options[hide_posts_navigation]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[posts_navigation_type]', array( 'default' => 'numberednavi', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_posts_navigation_type' ) );

    $wp_customize->add_control( 'gridbone_posts_navigation_type_control', array( 'label' => esc_html__( 'Posts Navigation Type', 'gridbone' ), 'description' => esc_html__('Select posts navigation type you need. If you activate WP-PageNavi plugin, this navigation will be replaced by WP-PageNavi navigation.', 'gridbone'), 'section' => 'gridbone_section_navigation', 'settings' => 'gridbone_options[posts_navigation_type]', 'type' => 'select', 'choices' => array( 'normalnavi' => esc_html__('Normal Navigation', 'gridbone'), 'numberednavi' => esc_html__('Numbered Navigation', 'gridbone') ) ) );

    /* Page options */
    $wp_customize->add_section( 'gridbone_section_page', array( 'title' => esc_html__( 'Page Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 190 ) );

    $wp_customize->add_setting( 'gridbone_options[thumbnail_link_page]', array( 'default' => 'yes', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_yes_no' ) );

    $wp_customize->add_control( 'gridbone_thumbnail_link_page_control', array( 'label' => esc_html__( 'Featured Image Link', 'gridbone' ), 'description' => esc_html__('Do you want the featured image in a page to be linked to its page?', 'gridbone'), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[thumbnail_link_page]', 'type' => 'select', 'choices' => array( 'yes' => esc_html__('Yes', 'gridbone'), 'no' => esc_html__('No', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_thumbnail]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_thumbnail_control', array( 'label' => esc_html__( 'Hide Featured Image from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_thumbnail]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[featured_media_under_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_featured_media_under_page_title_control', array( 'label' => esc_html__( 'Move Featured Image to Bottom of Page Title', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[featured_media_under_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_title_control', array( 'label' => esc_html__( 'Hide Page Header from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[remove_page_title_link]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_remove_page_title_link_control', array( 'label' => esc_html__( 'Remove Link from Single Page Title', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[remove_page_title_link]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_date]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_date_control', array( 'label' => esc_html__( 'Hide Page Date from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_date]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[page_date_type]', array( 'default' => 'updated', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_date_type' ) );

    $wp_customize->add_control( 'gridbone_page_date_type_control', array( 'label' => esc_html__( 'Page Date Type', 'gridbone' ), 'description' => esc_html__('You can choose to display published or updated date of your page.', 'gridbone'), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[page_date_type]', 'type' => 'select', 'choices' => array( 'published' => esc_html__('Published', 'gridbone'), 'updated' => esc_html__('Updated', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[page_published_date_text]', array( 'default' => esc_html__( 'Posted on', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_page_published_date_text_control', array( 'label' => esc_html__( 'Page Published Date Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before published page date. Default text is "Posted on".', 'gridbone'), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[page_published_date_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[page_updated_date_text]', array( 'default' => esc_html__( 'Last updated on', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_page_updated_date_text_control', array( 'label' => esc_html__( 'Page Updated Date Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before page updated date. Default text is "Last updated on".', 'gridbone'), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[page_updated_date_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_author]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_author_control', array( 'label' => esc_html__( 'Hide Page Author from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_author]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[page_author_text]', array( 'default' => esc_html__( 'Posted by', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_page_author_text_control', array( 'label' => esc_html__( 'Page Author Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before page author. Default text is "Posted by".', 'gridbone'), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[page_author_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_comments]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_comments_control', array( 'label' => esc_html__( 'Hide Comment Link from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_comments]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[page_comments_text]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_page_comments_text_control', array( 'label' => esc_html__( 'Page Comments Pre Text', 'gridbone' ), 'description' => esc_html__('Enter a text to display before page comments.', 'gridbone'), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[page_comments_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_comment_form]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_comment_form_control', array( 'label' => esc_html__( 'Hide Comments/Comment Form from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_comment_form]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_page_edit]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_page_edit_control', array( 'label' => esc_html__( 'Hide Edit Link from Single Page', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_page_edit]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_static_page_title]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_static_page_title_control', array( 'label' => esc_html__( 'Hide Page Header from Static Homepage', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_static_page_title]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_static_page_meta]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_static_page_meta_control', array( 'label' => esc_html__( 'Hide Page Meta Data (Page Date, Page Author, Comment Link) from Static Homepage', 'gridbone' ), 'section' => 'gridbone_section_page', 'settings' => 'gridbone_options[hide_static_page_meta]', 'type' => 'checkbox', ) );


    /* Social profiles options */
    $wp_customize->add_section( 'gridbone_section_social', array( 'title' => esc_html__( 'Social Links Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 240, ));

    $wp_customize->add_setting( 'gridbone_options[hide_social_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_social_buttons_control', array( 'label' => esc_html__( 'Hide Social + Search + Login/Logout Buttons', 'gridbone' ), 'description' => esc_html__('If you checked this option, there is no any effect from these option: "Show Search Button", "Show Login/Logout Button", "Show Random Post Button".', 'gridbone'), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[hide_social_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[show_search_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_show_search_button_control', array( 'label' => esc_html__( 'Show Search Button', 'gridbone' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'gridbone'), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[show_search_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[show_login_button]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_show_login_button_control', array( 'label' => esc_html__( 'Show Login/Logout Button', 'gridbone' ), 'description' => esc_html__('This option has no effect if you checked the option: "Hide Social + Search + Login/Logout Buttons"', 'gridbone'), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[show_login_button]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[twitterlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_twitterlink_control', array( 'label' => esc_html__( 'X URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[twitterlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[facebooklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_facebooklink_control', array( 'label' => esc_html__( 'Facebook URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[facebooklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[threadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_threadslink_control', array( 'label' => esc_html__( 'Threads URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[threadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[pinterestlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_pinterestlink_control', array( 'label' => esc_html__( 'Pinterest URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[pinterestlink]', 'type' => 'text' ) );
    
    $wp_customize->add_setting( 'gridbone_options[linkedinlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_linkedinlink_control', array( 'label' => esc_html__( 'Linkedin Link', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[linkedinlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[instagramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_instagramlink_control', array( 'label' => esc_html__( 'Instagram Link', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[instagramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[vklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_vklink_control', array( 'label' => esc_html__( 'VK Link', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[vklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[flickrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_flickrlink_control', array( 'label' => esc_html__( 'Flickr Link', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[flickrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[youtubelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_youtubelink_control', array( 'label' => esc_html__( 'Youtube URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[youtubelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[vimeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_vimeolink_control', array( 'label' => esc_html__( 'Vimeo URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[vimeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[soundcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_soundcloudlink_control', array( 'label' => esc_html__( 'Soundcloud URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[soundcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[messengerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_messengerlink_control', array( 'label' => esc_html__( 'Messenger URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[messengerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[whatsapplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_whatsapplink_control', array( 'label' => esc_html__( 'WhatsApp URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[whatsapplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[tiktoklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_tiktoklink_control', array( 'label' => esc_html__( 'TikTok URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[tiktoklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[lastfmlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_lastfmlink_control', array( 'label' => esc_html__( 'Lastfm URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[lastfmlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[mediumlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_mediumlink_control', array( 'label' => esc_html__( 'Medium URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[mediumlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[githublink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_githublink_control', array( 'label' => esc_html__( 'Github URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[githublink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[bitbucketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_bitbucketlink_control', array( 'label' => esc_html__( 'Bitbucket URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[bitbucketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[tumblrlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_tumblrlink_control', array( 'label' => esc_html__( 'Tumblr URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[tumblrlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[digglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_digglink_control', array( 'label' => esc_html__( 'Digg URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[digglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[deliciouslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_deliciouslink_control', array( 'label' => esc_html__( 'Delicious URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[deliciouslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[stumblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_stumblelink_control', array( 'label' => esc_html__( 'Stumbleupon URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[stumblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[mixlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_mixlink_control', array( 'label' => esc_html__( 'Mix URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[mixlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[redditlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_redditlink_control', array( 'label' => esc_html__( 'Reddit URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[redditlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[dribbblelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_dribbblelink_control', array( 'label' => esc_html__( 'Dribbble URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[dribbblelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[flipboardlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_flipboardlink_control', array( 'label' => esc_html__( 'Flipboard URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[flipboardlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[bloggerlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_bloggerlink_control', array( 'label' => esc_html__( 'Blogger URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[bloggerlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[etsylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_etsylink_control', array( 'label' => esc_html__( 'Etsy URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[etsylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[behancelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_behancelink_control', array( 'label' => esc_html__( 'Behance URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[behancelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[amazonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_amazonlink_control', array( 'label' => esc_html__( 'Amazon URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[amazonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[meetuplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_meetuplink_control', array( 'label' => esc_html__( 'Meetup URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[meetuplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[mixcloudlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_mixcloudlink_control', array( 'label' => esc_html__( 'Mixcloud URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[mixcloudlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[slacklink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_slacklink_control', array( 'label' => esc_html__( 'Slack URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[slacklink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[snapchatlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_snapchatlink_control', array( 'label' => esc_html__( 'Snapchat URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[snapchatlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[spotifylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_spotifylink_control', array( 'label' => esc_html__( 'Spotify URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[spotifylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[yelplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_yelplink_control', array( 'label' => esc_html__( 'Yelp URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[yelplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[wordpresslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_wordpresslink_control', array( 'label' => esc_html__( 'WordPress URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[wordpresslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[twitchlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_twitchlink_control', array( 'label' => esc_html__( 'Twitch URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[twitchlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[telegramlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_telegramlink_control', array( 'label' => esc_html__( 'Telegram URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[telegramlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[bandcamplink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_bandcamplink_control', array( 'label' => esc_html__( 'Bandcamp URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[bandcamplink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[quoralink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_quoralink_control', array( 'label' => esc_html__( 'Quora URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[quoralink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[foursquarelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_foursquarelink_control', array( 'label' => esc_html__( 'Foursquare URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[foursquarelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[deviantartlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_deviantartlink_control', array( 'label' => esc_html__( 'DeviantArt URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[deviantartlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[imdblink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_imdblink_control', array( 'label' => esc_html__( 'IMDB URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[imdblink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[codepenlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_codepenlink_control', array( 'label' => esc_html__( 'Codepen URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[codepenlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[jsfiddlelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_jsfiddlelink_control', array( 'label' => esc_html__( 'JSFiddle URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[jsfiddlelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[stackoverflowlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_stackoverflowlink_control', array( 'label' => esc_html__( 'Stack Overflow URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[stackoverflowlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[stackexchangelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_stackexchangelink_control', array( 'label' => esc_html__( 'Stack Exchange URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[stackexchangelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[bsalink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_bsalink_control', array( 'label' => esc_html__( 'BuySellAds URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[bsalink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[web500pxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_web500pxlink_control', array( 'label' => esc_html__( '500px URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[web500pxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[ellolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_ellolink_control', array( 'label' => esc_html__( 'Ello URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[ellolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[discordlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_discordlink_control', array( 'label' => esc_html__( 'Discord URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[discordlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[goodreadslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_goodreadslink_control', array( 'label' => esc_html__( 'Goodreads URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[goodreadslink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[odnoklassnikilink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_odnoklassnikilink_control', array( 'label' => esc_html__( 'Odnoklassniki URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[odnoklassnikilink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[houzzlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_houzzlink_control', array( 'label' => esc_html__( 'Houzz URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[houzzlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[pocketlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_pocketlink_control', array( 'label' => esc_html__( 'Pocket URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[pocketlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[xinglink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_xinglink_control', array( 'label' => esc_html__( 'XING URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[xinglink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[mastodonlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_mastodonlink_control', array( 'label' => esc_html__( 'Mastodon URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[mastodonlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[googleplaylink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_googleplaylink_control', array( 'label' => esc_html__( 'Google Play URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[googleplaylink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[slidesharelink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_slidesharelink_control', array( 'label' => esc_html__( 'SlideShare URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[slidesharelink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[dropboxlink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_dropboxlink_control', array( 'label' => esc_html__( 'Dropbox URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[dropboxlink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[paypallink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_paypallink_control', array( 'label' => esc_html__( 'PayPal URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[paypallink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[viadeolink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_viadeolink_control', array( 'label' => esc_html__( 'Viadeo URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[viadeolink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[wikipedialink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_wikipedialink_control', array( 'label' => esc_html__( 'Wikipedia URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[wikipedialink]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[skypeusername]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field' ) );

    $wp_customize->add_control( 'gridbone_skypeusername_control', array( 'label' => esc_html__( 'Skype Username', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[skypeusername]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[emailaddress]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_email' ) );

    $wp_customize->add_control( 'gridbone_emailaddress_control', array( 'label' => esc_html__( 'Email Address', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[emailaddress]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[rsslink]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'esc_url_raw' ) );

    $wp_customize->add_control( 'gridbone_rsslink_control', array( 'label' => esc_html__( 'RSS Feed URL', 'gridbone' ), 'section' => 'gridbone_section_social', 'settings' => 'gridbone_options[rsslink]', 'type' => 'text' ) );

    /* Share Button options */
    $wp_customize->add_section( 'gridbone_section_share', array( 'title' => esc_html__( 'Share Buttons Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 260 ) );

    $wp_customize->add_setting( 'gridbone_options[hide_share_buttons]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_share_buttons_control', array( 'label' => esc_html__( 'Hide Share Buttons from Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[hide_share_buttons]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_share_text]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_share_text_control', array( 'label' => esc_html__( 'Hide Share Text from Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[hide_share_text]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[share_text]', array( 'default' => esc_html__( 'Share:', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'sanitize_text_field', ) );

    $wp_customize->add_control( 'gridbone_share_text_control', array( 'label' => esc_html__( 'Share Text for Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[share_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_share_twitter]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_share_twitter_control', array( 'label' => esc_html__( 'Hide X Share Button from Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[hide_share_twitter]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_share_facebook]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_share_facebook_control', array( 'label' => esc_html__( 'Hide Facebook Share Button from Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[hide_share_facebook]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_share_pinterest]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_share_pinterest_control', array( 'label' => esc_html__( 'Hide Pinterest Share Button from Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[hide_share_pinterest]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_share_linkedin]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_share_linkedin_control', array( 'label' => esc_html__( 'Hide Linkedin Share Button from Single Posts', 'gridbone' ), 'section' => 'gridbone_section_share', 'settings' => 'gridbone_options[hide_share_linkedin]', 'type' => 'checkbox', ) );

    /* Footer options */
    $wp_customize->add_section( 'gridbone_section_footer', array( 'title' => esc_html__( 'Footer Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 280 ) );

    $wp_customize->add_setting( 'gridbone_options[footer_text]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_footer_text_control', array( 'label' => esc_html__( 'Footer Copyright Notice', 'gridbone' ), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_text]', 'type' => 'text', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_footer_widgets]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_footer_widgets_control', array( 'label' => esc_html__( 'Hide Footer Widgets', 'gridbone' ), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[hide_footer_widgets]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_backtotop]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_backtotop_control', array( 'label' => esc_html__( 'Disable Back to Top Button', 'gridbone' ), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[disable_backtotop]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[enable_footer_notice]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_footer_notice_control', array( 'label' => esc_html__( 'Enable Footer Notice', 'gridbone' ), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[enable_footer_notice]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[footer_notice_text]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_footer_notice_text_control', array( 'label' => esc_html__( 'Footer Notice', 'gridbone' ), 'description' => esc_html__( 'Enter a message to display in the footer notification area. You can add custom text or an ad code here.', 'gridbone' ), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_notice_text]', 'type' => 'textarea' ) );

    $wp_customize->add_setting( 'gridbone_options[footer_notice_display]', array( 'default' => 'everywhere', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_footer_notice_display' ) );

    $wp_customize->add_control( 'gridbone_footer_notice_display_control', array( 'label' => esc_html__( 'Footer Notice Display Location', 'gridbone' ), 'description' => esc_html__('Select the footer notice display location.', 'gridbone'), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_notice_display]', 'type' => 'select', 'choices' => array( 'front-page' => esc_html__('Home Page', 'gridbone'), 'front-page-static' => esc_html__('Static Home Page', 'gridbone'), 'blog-posts-index' => esc_html__( 'Blog Posts Index Page', 'gridbone' ), 'everywhere' => esc_html__('Everywhere', 'gridbone') ) ) );

    $wp_customize->add_setting( 'gridbone_options[no_center_footer_notice]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_no_center_footer_notice_control', array( 'label' => esc_html__( 'Do not Center Footer Notice', 'gridbone' ), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[no_center_footer_notice]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[footer_content_image]', array( 'default' => '', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'absint' ) );

    $wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'gridbone_footer_content_image_control', array(
        'label' => esc_html__( 'Footer Content Background Image', 'gridbone' ),
        'flex_width' => true,
        'flex_height' => true,
        'section' => 'gridbone_section_footer',
        'settings' => 'gridbone_options[footer_content_image]',
        'button_labels' => array( 'select' => esc_html__( 'Select Image', 'gridbone' ), 'remove' => esc_html__( 'Remove Image', 'gridbone' ), 'change' => esc_html__( 'Change Image', 'gridbone' ), )
    )));

    $wp_customize->add_setting( 'gridbone_options[footer_content_bg_size]', array( 'default' => 'cover', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_size' ) );

    $wp_customize->add_control( 'gridbone_footer_content_bg_size_control', array( 'label' => esc_html__( 'Footer Content Background Image Size', 'gridbone' ), 'description' => esc_html__('Select the background size value for footer content background image. Default value: Cover', 'gridbone'), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_content_bg_size]', 'type' => 'select', 'choices' => array( 'auto' => esc_html__( 'Auto', 'gridbone' ), 'cover' => esc_html__( 'Cover', 'gridbone' ), 'contain' => esc_html__( 'Contain', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[footer_content_bg_position]', array( 'default' => 'center top', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_position' ) );

    $wp_customize->add_control( 'gridbone_footer_content_bg_position_control', array( 'label' => esc_html__( 'Footer Content Background Image Position', 'gridbone' ), 'description' => esc_html__('Select the background position value for footer content background image. Default value: Center Top', 'gridbone'), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_content_bg_position]', 'type' => 'select', 'choices' => array( 'left top' => esc_html__( 'Left Top', 'gridbone' ), 'left center' => esc_html__( 'Left Center', 'gridbone' ), 'left bottom' => esc_html__( 'Left Bottom', 'gridbone' ), 'right top' => esc_html__( 'Right Top', 'gridbone' ), 'right center' => esc_html__( 'Right Center', 'gridbone' ), 'right bottom' => esc_html__( 'Right Bottom', 'gridbone' ), 'center top' => esc_html__( 'Center Top', 'gridbone' ), 'center center' => esc_html__( 'Center Center', 'gridbone' ), 'center bottom' => esc_html__( 'Center Bottom', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[footer_content_bg_attachment]', array( 'default' => 'scroll', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_attachment' ) );

    $wp_customize->add_control( 'gridbone_footer_content_bg_attachment_control', array( 'label' => esc_html__( 'Footer Content Background Image Attachment', 'gridbone' ), 'description' => esc_html__('Select the background attachment value for footer content background image. Default value: Scroll', 'gridbone'), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_content_bg_attachment]', 'type' => 'select', 'choices' => array( 'scroll' => esc_html__( 'Scroll', 'gridbone' ), 'fixed' => esc_html__( 'Fixed', 'gridbone' ), 'local' => esc_html__( 'Local', 'gridbone' ) ) ) );

    $wp_customize->add_setting( 'gridbone_options[footer_content_bg_repeat]', array( 'default' => 'no-repeat', 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_bg_repeat' ) );

    $wp_customize->add_control( 'gridbone_footer_content_bg_repeat_control', array( 'label' => esc_html__( 'Footer Content Background Image Repeat', 'gridbone' ), 'description' => esc_html__('Select the background repeat value for footer content background image. Default value: no-repeat', 'gridbone'), 'section' => 'gridbone_section_footer', 'settings' => 'gridbone_options[footer_content_bg_repeat]', 'type' => 'select', 'choices' => array( 'repeat' => esc_html__( 'repeat', 'gridbone' ), 'repeat-x' => esc_html__( 'repeat-x', 'gridbone' ), 'repeat-y' => esc_html__( 'repeat-y', 'gridbone' ), 'no-repeat' => esc_html__( 'no-repeat', 'gridbone' ) ) ) );

    /* 404 options */
    $wp_customize->add_section( 'gridbone_section_search_404', array( 'title' => esc_html__( 'Search and 404 Pages Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 340 ) );

    $wp_customize->add_setting( 'gridbone_options[no_search_heading]', array( 'default' => esc_html__( 'Nothing Found', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_no_search_heading_control', array( 'label' => esc_html__( 'No Search Results Heading', 'gridbone' ), 'description' => esc_html__( 'Enter a heading to display when no search results are found.', 'gridbone' ), 'section' => 'gridbone_section_search_404', 'settings' => 'gridbone_options[no_search_heading]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[no_search_results]', array( 'default' => esc_html__( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_no_search_results_control', array( 'label' => esc_html__( 'No Search Results Message', 'gridbone' ), 'description' => esc_html__( 'Enter a message to display when no search results are found.', 'gridbone' ), 'section' => 'gridbone_section_search_404', 'settings' => 'gridbone_options[no_search_results]', 'type' => 'textarea' ) );

    $wp_customize->add_setting( 'gridbone_options[error_404_heading]', array( 'default' => esc_html__( 'Oops! That page can not be found.', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_error_404_heading_control', array( 'label' => esc_html__( '404 Error Page Heading', 'gridbone' ), 'description' => esc_html__( 'Enter the heading for the 404 error page.', 'gridbone' ), 'section' => 'gridbone_section_search_404', 'settings' => 'gridbone_options[error_404_heading]', 'type' => 'text' ) );

    $wp_customize->add_setting( 'gridbone_options[error_404_message]', array( 'default' => esc_html__( 'It looks like nothing was found at this location. Maybe try one of the links below or a search?', 'gridbone' ), 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_html', ) );

    $wp_customize->add_control( 'gridbone_error_404_message_control', array( 'label' => esc_html__( 'Error 404 Message', 'gridbone' ), 'description' => esc_html__( 'Enter a message to display on the 404 error page.', 'gridbone' ), 'section' => 'gridbone_section_search_404', 'settings' => 'gridbone_options[error_404_message]', 'type' => 'textarea', ) );

    $wp_customize->add_setting( 'gridbone_options[hide_404_search]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_hide_404_search_control', array( 'label' => esc_html__( 'Hide Search Box from 404 Page', 'gridbone' ), 'section' => 'gridbone_section_search_404', 'settings' => 'gridbone_options[hide_404_search]', 'type' => 'checkbox', ) );

    /* Other options */
    $wp_customize->add_section( 'gridbone_section_other_options', array( 'title' => esc_html__( 'Other Options', 'gridbone' ), 'panel' => 'gridbone_main_options_panel', 'priority' => 600 ) );

    $wp_customize->add_setting( 'gridbone_options[enable_widgets_block_editor]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_enable_widgets_block_editor_control', array( 'label' => esc_html__( 'Enable Gutenberg Widget Block Editor', 'gridbone' ), 'section' => 'gridbone_section_other_options', 'settings' => 'gridbone_options[enable_widgets_block_editor]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_loading_animation]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_loading_animation_control', array( 'label' => esc_html__( 'Disable Site Loading Animation', 'gridbone' ), 'section' => 'gridbone_section_other_options', 'settings' => 'gridbone_options[disable_loading_animation]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_sticky_sidebar]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_sticky_sidebar_control', array( 'label' => esc_html__( 'Disable Sticky Feature from Sidebars', 'gridbone' ), 'section' => 'gridbone_section_other_options', 'settings' => 'gridbone_options[disable_sticky_sidebar]', 'type' => 'checkbox', ) );

    $wp_customize->add_setting( 'gridbone_options[disable_fitvids]', array( 'default' => false, 'type' => 'option', 'capability' => 'edit_theme_options', 'sanitize_callback' => 'gridbone_sanitize_checkbox', ) );

    $wp_customize->add_control( 'gridbone_disable_fitvids_control', array( 'label' => esc_html__( 'Disable FitVids.JS', 'gridbone' ), 'description' => esc_html__( 'You can disable fitvids.js script if you are not using videos on your website or if you do not want fluid width videos in your post content.', 'gridbone' ), 'section' => 'gridbone_section_other_options', 'settings' => 'gridbone_options[disable_fitvids]', 'type' => 'checkbox', ) );

    /* Upgrade to pro options */
    $wp_customize->add_section( 'gridbone_section_upgrade', array( 'title' => esc_html__( 'Upgrade to Pro Version', 'gridbone' ), 'priority' => 400 ) );
    
    $wp_customize->add_setting( 'gridbone_options[upgrade_text]', array( 'default' => '', 'sanitize_callback' => '__return_false', ) );
    
    $wp_customize->add_control( new GridBone_Customize_Static_Text_Control( $wp_customize, 'gridbone_upgrade_text_control', array(
        'label'       => esc_html__( 'GridBone Pro', 'gridbone' ),
        'section'     => 'gridbone_section_upgrade',
        'settings' => 'gridbone_options[upgrade_text]',
        'description' => esc_html__( 'Do you enjoy GridBone? Upgrade to GridBone Pro now and get:', 'gridbone' ).
            '<ul class="gridbone-customizer-pro-features">' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Color Options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Font Options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Custom URL Support for Grid Posts', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Featured Image URL Support for Grid Posts', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Custom Thumbnail Support for Grid Posts', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Custom Title Support for Grid Posts', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Lightbox Feature for Grid Thumbnails', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Open Grid Posts in New Windows/New Tabs', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Add Nofollow Attribute to Grid Post URLs', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Featured Posts Slider with More Options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Switch between Boxed or Full Layout Type', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( '10+ Layout Styles for Posts/Pages', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( '10+ Layout Styles for Non-Singular Pages', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Width Change Options for Full Website/Main Content/Left Sidebar/Right Sidebar', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( '10+ Custom Page Templates', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( '10+ Custom Post Templates', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( '8 Header Layouts', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Footer with Layout Options (1/2/3/4/5/6 columns)', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to Change Website Width/Layout Type/Layout Style/Header Style/Footer Style of any Post/Page', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Capability to Add Different Header Images for Each Post/Page with Unique Link, Title and Description', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Capability to Add Different Header Notifications/Ads for Each Post/Page', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Capability to Add Different Footer Notifications/Ads for Each Post/Page', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Grid Featured Posts Widget (Recent/Categories/Tags/PostIDs based) - with capability to display posts according to Likes/Views/Comments/Dates/... and there are many options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'List Featured Posts Widget (Recent/Categories/Tags/PostIDs based) - with capability to display posts according to Likes/Views/Comments/Dates/... and there are many options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Tabbed Featured Posts Widget (Recent/Categories/Tags/PostIDs based) - with capability to display posts according to Likes/Views/Comments/Dates/... and there are many options.', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'About and Social Widget - 60+ Social Buttons', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'News Ticker (Recent/Categories/Tags/PostIDs based) - It can display posts according to Likes/Views/Comments/Dates/... and there are many options.', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Settings Panel to Control Options in Each Post', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Settings Panel to Control Options in Each Page', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Display Ads/Custom Contents between Posts in the Grid', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Posts Views Counter', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Posts Likes System', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Infinite Scroll and Load More Button', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Post Share Buttons with Options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Related Posts (Categories/Tags/Author/PostIDs based) with Many Options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Sticky Menu/Sticky Sidebars with enable/disable capability', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Author Bio Box with Social Buttons - 60+ Social Buttons', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to Enable/Disable Mobile View from Header, Primary and Secondary Menus', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Post Navigation with Thumbnails', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to add Different Ads under Post Title and under Post Content for Each Post', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Different Header Background Image Support for Each Post/Page', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Different Footer Background Image Support for Each Post/Page', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Ability to Disable Google Fonts - for faster loading', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'More Widget Areas', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Built-in Contact Form', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'WooCommerce Compatible', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Yoast SEO Breadcrumbs Support', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Full RTL Language Support', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Search Engine Optimized', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Random Posts Button in Header', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'Many Useful Customizer Theme options', 'gridbone' ) . '</li>' .
                '<li><i class="fas fa-check" aria-hidden="true"></i> ' . esc_html__( 'More Features...', 'gridbone' ) . '</li>' .
            '</ul>'.
            '<strong><a href="'.GRIDBONE_PROURL.'" class="button button-primary" target="_blank"><i class="fas fa-shopping-cart" aria-hidden="true"></i> ' . esc_html__( 'Upgrade To GridBone PRO', 'gridbone' ) . '</a></strong>'
    ) ) );

}

add_action( 'customize_register', 'gridbone_register_theme_customizer' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function gridbone_customize_partial_blogname() {
    bloginfo( 'name' );
}
/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function gridbone_customize_partial_blogdescription() {
    bloginfo( 'description' );
}

function gridbone_customizer_js_scripts() {
    wp_enqueue_script('gridbone-theme-customizer-js', get_template_directory_uri() . '/assets/js/customizer.js', array( 'jquery', 'customize-preview' ), null, true);
}
add_action( 'customize_preview_init', 'gridbone_customizer_js_scripts' );